<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>Повторяющийся</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>Расширить</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>Только на %1</translation>
    </message>
</context>
</TS>